@@ -44,11 +44,10 @@
 #include <QtCore/qobject.h>
 #include <QtWidgets/qstyleoption.h>
 
+QT_REQUIRE_CONFIG(itemviews);
+
 QT_BEGIN_NAMESPACE
 
-
-#ifndef QT_NO_ITEMVIEWS
-
 class QPainter;
 class QModelIndex;
 class QAbstractItemModel;
@@ -127,8 +126,6 @@ private:
     Q_PRIVATE_SLOT(d_func(), void _q_commitDataAndCloseEditor(QWidget*))
 };
 
-#endif // QT_NO_ITEMVIEWS
-
 QT_END_NAMESPACE
 
 #endif // QABSTRACTITEMDELEGATE_H
